version 17

log close _all
clear all
macro drop _all
set linesize 82

log using "./logs/example do-file.smcl", replace name(master)



**# HEADER
**========
type ./header.txt





**#1. Load Settings (from .do)
**============================
do ./config/settings








**#2. Compute Grades from Exam Data
*==================================
macro list rawdata
use "$rawdata", clear


do ./code/grading








**#3. Export Anonymous Grades List
*=================================
label var ID        "Student ID"
label var total     "Total points"
label var grade     "Overall grade"

export excel  ID total grade  using "$gradeslist", ///
  firstrow(varlabels) replace








**#4. Plot Grade Distribution
*============================
preserve
    gen one = 1
    collapse (count) freq=one , by(grade)

    sum freq
    
    graph bar (asis) freq, over(grade, label(labcolor($text_color)))  ///
        title(`"Grade Distribution {it:"$title"}"', color($text_color) span)  ///
        ytitle("")  ///
        ylabel(, angle(0) labcolor($text_color))  ///
        bar(1, color($bar_color))  ///
        blabel(bar, pos(inside) color(white))  ///
        caption("{it:N} = `r(sum)'", color($text_color) position(5))  ///
        graphregion(color(white))

    graph export "./results/barplot grades $shorttitle $term.svg", replace
restore




********************************************************************************
log close master
translate "./logs/example do-file.smcl" "./logs/example do-file.pdf", replace
exit
